{
  am_pm_abbreviated => [
    "\N{U+05e4}\N{U+05bf}\N{U+05d0}\N{U+05b7}\N{U+05e8}\N{U+05de}\N{U+05d9}\N{U+05d8}\N{U+05d0}\N{U+05b8}\N{U+05d2}",
    "\N{U+05e0}\N{U+05d0}\N{U+05b8}\N{U+05db}\N{U+05de}\N{U+05d9}\N{U+05d8}\N{U+05d0}\N{U+05b8}\N{U+05d2}",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E \N{U+05d3}\N{U+05e2}\N{U+05dd} d\N{U+05d8}\N{U+05df}",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "E \N{U+05d3}\N{U+05e2}\N{U+05dd} d\N{U+05d8}\N{U+05df} MMM yG",
    GyMMMd => "d\N{U+05d8}\N{U+05df} MMM y G",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "E, d/M/y",
    yMM => "MM/y",
    yMMM => "MMM y",
    yMMMEd => "E, d\N{U+05d8}\N{U+05df} MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d\N{U+05d8}\N{U+05df} MMM y",
    yMd => "d-M-y",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "yi",
  date_format_full => "EEEE, d\N{U+05d8}\N{U+05df} MMMM y",
  date_format_long => "d\N{U+05d8}\N{U+05df} MMMM y",
  date_format_medium => "d\N{U+05d8}\N{U+05df} MMM y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+05de}\N{U+05d0}\N{U+05b8}\N{U+05e0}\N{U+05d8}\N{U+05d9}\N{U+05e7}",
    "\N{U+05d3}\N{U+05d9}\N{U+05e0}\N{U+05e1}\N{U+05d8}\N{U+05d9}\N{U+05e7}",
    "\N{U+05de}\N{U+05d9}\N{U+05d8}\N{U+05d5}\N{U+05d5}\N{U+05d0}\N{U+05da}",
    "\N{U+05d3}\N{U+05d0}\N{U+05e0}\N{U+05e2}\N{U+05e8}\N{U+05e9}\N{U+05d8}\N{U+05d9}\N{U+05e7}",
    "\N{U+05e4}\N{U+05bf}\N{U+05e8}\N{U+05f2}\N{U+05b7}\N{U+05d8}\N{U+05d9}\N{U+05e7}",
    "\N{U+05e9}\N{U+05d1}\N{U+05ea}",
    "\N{U+05d6}\N{U+05d5}\N{U+05e0}\N{U+05d8}\N{U+05d9}\N{U+05e7}",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "\N{U+05de}\N{U+05d0}\N{U+05b8}\N{U+05e0}\N{U+05d8}\N{U+05d9}\N{U+05e7}",
    "\N{U+05d3}\N{U+05d9}\N{U+05e0}\N{U+05e1}\N{U+05d8}\N{U+05d9}\N{U+05e7}",
    "\N{U+05de}\N{U+05d9}\N{U+05d8}\N{U+05d5}\N{U+05d5}\N{U+05d0}\N{U+05da}",
    "\N{U+05d3}\N{U+05d0}\N{U+05e0}\N{U+05e2}\N{U+05e8}\N{U+05e9}\N{U+05d8}\N{U+05d9}\N{U+05e7}",
    "\N{U+05e4}\N{U+05bf}\N{U+05e8}\N{U+05f2}\N{U+05b7}\N{U+05d8}\N{U+05d9}\N{U+05e7}",
    "\N{U+05e9}\N{U+05d1}\N{U+05ea}",
    "\N{U+05d6}\N{U+05d5}\N{U+05e0}\N{U+05d8}\N{U+05d9}\N{U+05e7}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+05de}\N{U+05d0}\N{U+05b8}\N{U+05e0}\N{U+05d8}\N{U+05d9}\N{U+05e7}",
    "\N{U+05d3}\N{U+05d9}\N{U+05e0}\N{U+05e1}\N{U+05d8}\N{U+05d9}\N{U+05e7}",
    "\N{U+05de}\N{U+05d9}\N{U+05d8}\N{U+05d5}\N{U+05d5}\N{U+05d0}\N{U+05da}",
    "\N{U+05d3}\N{U+05d0}\N{U+05e0}\N{U+05e2}\N{U+05e8}\N{U+05e9}\N{U+05d8}\N{U+05d9}\N{U+05e7}",
    "\N{U+05e4}\N{U+05bf}\N{U+05e8}\N{U+05f2}\N{U+05b7}\N{U+05d8}\N{U+05d9}\N{U+05e7}",
    "\N{U+05e9}\N{U+05d1}\N{U+05ea}",
    "\N{U+05d6}\N{U+05d5}\N{U+05e0}\N{U+05d8}\N{U+05d9}\N{U+05e7}",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "\N{U+05de}\N{U+05d0}\N{U+05b8}\N{U+05e0}\N{U+05d8}\N{U+05d9}\N{U+05e7}",
    "\N{U+05d3}\N{U+05d9}\N{U+05e0}\N{U+05e1}\N{U+05d8}\N{U+05d9}\N{U+05e7}",
    "\N{U+05de}\N{U+05d9}\N{U+05d8}\N{U+05d5}\N{U+05d5}\N{U+05d0}\N{U+05da}",
    "\N{U+05d3}\N{U+05d0}\N{U+05e0}\N{U+05e2}\N{U+05e8}\N{U+05e9}\N{U+05d8}\N{U+05d9}\N{U+05e7}",
    "\N{U+05e4}\N{U+05bf}\N{U+05e8}\N{U+05f2}\N{U+05b7}\N{U+05d8}\N{U+05d9}\N{U+05e7}",
    "\N{U+05e9}\N{U+05d1}\N{U+05ea}",
    "\N{U+05d6}\N{U+05d5}\N{U+05e0}\N{U+05d8}\N{U+05d9}\N{U+05e7}",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "BCE",
    "CE",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Yiddish",
  month_format_abbreviated => [
    "\N{U+05d9}\N{U+05d0}\N{U+05b7}\N{U+05e0}\N{U+05d5}\N{U+05d0}\N{U+05b7}\N{U+05e8}",
    "\N{U+05e4}\N{U+05bf}\N{U+05e2}\N{U+05d1}\N{U+05e8}\N{U+05d5}\N{U+05d0}\N{U+05b7}\N{U+05e8}",
    "\N{U+05de}\N{U+05e2}\N{U+05e8}\N{U+05e5}",
    "\N{U+05d0}\N{U+05b7}\N{U+05e4}\N{U+05bc}\N{U+05e8}\N{U+05d9}\N{U+05dc}",
    "\N{U+05de}\N{U+05d9}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05e0}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dc}\N{U+05d9}",
    "\N{U+05d0}\N{U+05d5}\N{U+05d9}\N{U+05d2}\N{U+05d5}\N{U+05e1}\N{U+05d8}",
    "\N{U+05e1}\N{U+05e2}\N{U+05e4}\N{U+05bc}\N{U+05d8}\N{U+05e2}\N{U+05de}\N{U+05d1}\N{U+05e2}\N{U+05e8}",
    "\N{U+05d0}\N{U+05e7}\N{U+05d8}\N{U+05d0}\N{U+05d1}\N{U+05e2}\N{U+05e8}",
    "\N{U+05e0}\N{U+05d0}\N{U+05d5}\N{U+05d5}\N{U+05e2}\N{U+05de}\N{U+05d1}\N{U+05e2}\N{U+05e8}",
    "\N{U+05d3}\N{U+05e2}\N{U+05e6}\N{U+05e2}\N{U+05de}\N{U+05d1}\N{U+05e2}\N{U+05e8}",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "\N{U+05d9}\N{U+05d0}\N{U+05b7}\N{U+05e0}\N{U+05d5}\N{U+05d0}\N{U+05b7}\N{U+05e8}",
    "\N{U+05e4}\N{U+05bf}\N{U+05e2}\N{U+05d1}\N{U+05e8}\N{U+05d5}\N{U+05d0}\N{U+05b7}\N{U+05e8}",
    "\N{U+05de}\N{U+05e2}\N{U+05e8}\N{U+05e5}",
    "\N{U+05d0}\N{U+05b7}\N{U+05e4}\N{U+05bc}\N{U+05e8}\N{U+05d9}\N{U+05dc}",
    "\N{U+05de}\N{U+05d9}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05e0}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dc}\N{U+05d9}",
    "\N{U+05d0}\N{U+05d5}\N{U+05d9}\N{U+05d2}\N{U+05d5}\N{U+05e1}\N{U+05d8}",
    "\N{U+05e1}\N{U+05e2}\N{U+05e4}\N{U+05bc}\N{U+05d8}\N{U+05e2}\N{U+05de}\N{U+05d1}\N{U+05e2}\N{U+05e8}",
    "\N{U+05d0}\N{U+05e7}\N{U+05d8}\N{U+05d0}\N{U+05d1}\N{U+05e2}\N{U+05e8}",
    "\N{U+05e0}\N{U+05d0}\N{U+05d5}\N{U+05d5}\N{U+05e2}\N{U+05de}\N{U+05d1}\N{U+05e2}\N{U+05e8}",
    "\N{U+05d3}\N{U+05e2}\N{U+05e6}\N{U+05e2}\N{U+05de}\N{U+05d1}\N{U+05e2}\N{U+05e8}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+05d9}\N{U+05d0}\N{U+05b7}\N{U+05e0}",
    "\N{U+05e4}\N{U+05bf}\N{U+05e2}\N{U+05d1}",
    "\N{U+05de}\N{U+05e2}\N{U+05e8}\N{U+05e5}",
    "\N{U+05d0}\N{U+05b7}\N{U+05e4}\N{U+05bc}\N{U+05e8}",
    "\N{U+05de}\N{U+05d9}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05e0}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dc}\N{U+05d9}",
    "\N{U+05d0}\N{U+05d5}\N{U+05d9}\N{U+05d2}",
    "\N{U+05e1}\N{U+05e2}\N{U+05e4}\N{U+05bc}",
    "\N{U+05d0}\N{U+05e7}\N{U+05d8}",
    "\N{U+05e0}\N{U+05d0}\N{U+05d5}\N{U+05d5}",
    "\N{U+05d3}\N{U+05e2}\N{U+05e6}",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "\N{U+05d9}\N{U+05d0}\N{U+05b7}\N{U+05e0}\N{U+05d5}\N{U+05d0}\N{U+05b7}\N{U+05e8}",
    "\N{U+05e4}\N{U+05bf}\N{U+05e2}\N{U+05d1}\N{U+05e8}\N{U+05d5}\N{U+05d0}\N{U+05b7}\N{U+05e8}",
    "\N{U+05de}\N{U+05e2}\N{U+05e8}\N{U+05e5}",
    "\N{U+05d0}\N{U+05b7}\N{U+05e4}\N{U+05bc}\N{U+05e8}\N{U+05d9}\N{U+05dc}",
    "\N{U+05de}\N{U+05d9}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05e0}\N{U+05d9}",
    "\N{U+05d9}\N{U+05d5}\N{U+05dc}\N{U+05d9}",
    "\N{U+05d0}\N{U+05d5}\N{U+05d9}\N{U+05d2}\N{U+05d5}\N{U+05e1}\N{U+05d8}",
    "\N{U+05e1}\N{U+05e2}\N{U+05e4}\N{U+05bc}\N{U+05d8}\N{U+05e2}\N{U+05de}\N{U+05d1}\N{U+05e2}\N{U+05e8}",
    "\N{U+05d0}\N{U+05e7}\N{U+05d8}\N{U+05d0}\N{U+05d1}\N{U+05e2}\N{U+05e8}",
    "\N{U+05e0}\N{U+05d0}\N{U+05d5}\N{U+05d5}\N{U+05e2}\N{U+05de}\N{U+05d1}\N{U+05e2}\N{U+05e8}",
    "\N{U+05d3}\N{U+05e2}\N{U+05e6}\N{U+05e2}\N{U+05de}\N{U+05d1}\N{U+05e2}\N{U+05e8}",
  ],
  name => "Yiddish",
  native_language => "\N{U+05d9}\N{U+05d9}\N{U+05b4}\N{U+05d3}\N{U+05d9}\N{U+05e9}",
  native_name => "\N{U+05d9}\N{U+05d9}\N{U+05b4}\N{U+05d3}\N{U+05d9}\N{U+05e9}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 46,
}
